distributions.is_ordered_pair()
Validates that two values are in ascending order (low < high).
Usage
distributions.is_ordered_pair(
low,
high,
low_name="low",
high_name="high",
)Validates that two values are in ascending order (low < high).
Usage