output_analysis.AlgorithmObserver
Protocol for observer classes used in ReplicationsAlgorithm.
Usage
output_analysis.AlgorithmObserver()Classes implementing this protocol should provide a dev attribute to store observations, a method update to add new results, and a summary_table method to summarize the stored replication statistics.
Attributes
dev: List[Any]- Collection of observed replication results.