output_analysis.ReplicationsAlgorithmModelAdapter
Adapter pattern for the “Replications Algorithm”.
Usage
output_analysis.ReplicationsAlgorithmModelAdapter()All models that use ReplicationsAlgorithm must provide a single_run(replication_number) interface.
Methods
| Name | Description |
|---|---|
| single_run() | Run a single unique replication of the model and return results. |
single_run()
Run a single unique replication of the model and return results.
Usage
single_run(replication_number)Parameters
replication_number: int- The replication sequence number.
Returns
dict[str, float]- {‘metric_name’: value, … } for all metrics being tracked.