time_dependent.nspp_plot()
Generate a matplotlib chart to visualise a non-stationary poisson process
Usage
time_dependent.nspp_plot(
arrival_profile,
run_length=None,
n_reps=1000,
)for the set arrival profile.
This uses the sim-tools NSPPThinning class.
Useful for validating the the NSPP has been set up correctly and is producing the desired profile for the simulation model.
Parameters
arrival_profile: pd.DataFrame-
The arrival profile is a pandas data frame containing ‘t’, ‘arrival_rate’ and ‘mean_iat’ columns.
run_length: Optional[float] = None-
How long should the simulation be run. If none then uses the last value in ‘t’ + the interval (assumes equal width intervals)
n_reps: Optional[int] = 1000- The number of replications to run.